@@ -21,34 +21,6 @@
 
 #include "intl.h"
 
-class ActivateWindowMenuItem: public YMenuItem {
-public:
-    ActivateWindowMenuItem(YFrameWindow *frame):
-        YMenuItem(frame->getTitle(), -1, null, YAction(), nullptr),
-        fFrame(frame)
-    {
-        if (fFrame->clientIcon() != null)
-            setIcon(fFrame->clientIcon());
-    }
-
-    virtual void actionPerformed(YActionListener * /*listener*/, YAction /*action*/, unsigned int modifiers) {
-        YFrameWindow *f = manager->topLayer();
-
-        while (f) {
-            if ((void *)f == fFrame) {
-                if (modifiers & ShiftMask)
-                    f->wmOccupyOnlyWorkspace(manager->activeWorkspace());
-                f->activateWindow(true, false);
-                return ;
-            }
-            f = f->nextLayer();
-        }
-    }
-private:
-    YFrameWindow *fFrame;
-};
-
-
 YMenu *YWindowManager::createWindowMenu(YMenu *menu, long workspace) {
     if (!menu)
         menu = new YMenu();
@@ -71,8 +43,7 @@ YMenu *YWindowManager::createWindowMenu(YMenu *menu, long workspace) {
                     continue;
                 if (frame->frameOption(YFrameWindow::foIgnoreWinList))
                     continue;
-                if (workspace != activeWorkspace() &&
-                    frame->visibleOn(activeWorkspace()))
+                if (workspace != activeWorkspace() && frame->visibleNow())
                     continue;
 
                 windowLevel = 0;
@@ -90,16 +61,41 @@ YMenu *YWindowManager::createWindowMenu(YMenu *menu, long workspace) {
                     ((layerCount == 0 && layer > 0) && needSeparator))
                     menu->addSeparator();
 
-                menu->add(new ActivateWindowMenuItem(frame));
+                YAction action(EAction(int(frame->handle())));
+                YMenuItem* item = new YMenuItem(frame->getTitle(), -1, null,
+                                                action, nullptr);
+                if (item) {
+                    if (frame->clientIcon() != null)
+                        item->setIcon(frame->clientIcon());
+                    menu->add(item);
+                }
                 levelCount++;
                 layerCount++;
                 needSeparator = true;
             }
         }
     }
+    menu->setActionListener(this);
     return menu;
 }
 
+void YWindowManager::actionPerformed(YAction action, unsigned modifiers) {
+    for (YFrameWindow *f = manager->topLayer(); f; f = f->nextLayer()) {
+        if (int(f->handle()) == action.ident()) {
+            if (modifiers & ShiftMask)
+                f->wmOccupyWorkspace(manager->activeWorkspace());
+            f->activateWindow(true, false);
+            return ;
+        }
+    }
+    for (int w = 0; w < workspaceCount; w++) {
+        if (workspaceActionActivate[w] == action) {
+            activateWorkspace(w);
+            return ;
+        }
+    }
+}
+
 WindowListMenu::WindowListMenu(YActionListener *app, YWindow *parent):
     YMenu(parent)
 {
